==> haskell-wai-app-file-cgi-3.1.11-2-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-wai-app-file-cgi.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 wai-app-file-cgi
version:              3.1.11
visibility:           public
id:                   wai-app-file-cgi-3.1.11-1Qe3x5JfDb9CKHvd4YbcF9
key:                  wai-app-file-cgi-3.1.11-1Qe3x5JfDb9CKHvd4YbcF9
license:              BSD-3-Clause
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Kazu Yamamoto <kazu@iij.ad.jp>
homepage:             http://www.mew.org/~kazu/proj/mighttpd/
synopsis:             File/CGI/Rev Proxy App of WAI
description:
    This WAI application library handles static files,
    executes CGI scripts, and serves as a reverse proxy
    (including EventSource).

category:             Web, Yesod
abi:                  16cf0b208e05428e93175c91ba2b3e14
exposed:              True
exposed-modules:      Network.Wai.Application.Classic
hidden-modules:
    Network.Wai.Application.Classic.CGI
    Network.Wai.Application.Classic.Conduit
    Network.Wai.Application.Classic.Def
    Network.Wai.Application.Classic.EventSource
    Network.Wai.Application.Classic.Field
    Network.Wai.Application.Classic.File
    Network.Wai.Application.Classic.FileInfo
    Network.Wai.Application.Classic.Header
    Network.Wai.Application.Classic.Lang
    Network.Wai.Application.Classic.Path
    Network.Wai.Application.Classic.Redirect
    Network.Wai.Application.Classic.Status
    Network.Wai.Application.Classic.Types
    Network.Wai.Application.Classic.RevProxy

import-dirs:          /usr/lib/ghc-9.4.8/site-local/wai-app-file-cgi-3.1.11
library-dirs:         /usr/lib/ghc-9.4.8/site-local/wai-app-file-cgi-3.1.11
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/wai-app-file-cgi-3.1.11
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-wai-app-file-cgi
hs-libraries:         HSwai-app-file-cgi-3.1.11-1Qe3x5JfDb9CKHvd4YbcF9
depends:
    array-0.5.4.0 attoparsec-0.14.4-IjP3u1baQ7d7AdktrTB8o9
    base-4.17.2.1 bytestring-0.11.5.3
    case-insensitive-1.2.1.0-DLRBsz9VfqUNwIWg4HsHR
    conduit-1.3.6.1-EW1DZSLxYltGXIcrYWVDWp
    conduit-extra-1.3.8-DOUKw0fE0l5Jtslu93zZRD containers-0.6.7
    data-default-class-0.1.2.2-2EcHBs5cfSFLku8331ZnRi directory-1.3.7.1
    filepath-1.4.2.2 http-client-0.7.19-Je5Ncol09LTKkFF5WfHhv1
    http-conduit-2.3.9.1-ACc0PY7fQ3546ONqFA19yU
    http-date-0.0.11-Nu7pNpbJ1oBdk7BcojSNg
    http-types-0.12.4-6ojMayzAfwB91OTgOklzJ2
    mime-types-0.1.2.0-3JrdaebXJwiILES3glDFuq
    network-3.1.4.0-1n8WDlzhAQUHYfqI16mYdv process-1.6.18.0
    sockaddr-0.0.1-KFtQEghKKSw6EBYef6LeWg
    static-hash-0.0.2-JReMKK57SUMLmoOcQ3Zazj text-2.0.2
    transformers-0.5.6.2 unix-2.7.3 wai-3.2.4-HXL0p0WqRSGJXNDZnyl0Hj
    wai-conduit-3.0.0.4-ISTH0aWniHu55vfSyR0SYP
    warp-3.4.0-9odkFZsHMyT9nAjq8C8gI1
    word8-0.1.3-H2XlNdB8B5CGwrdA9Iis9I

haddock-interfaces:
    /usr/share/doc/haskell-wai-app-file-cgi/html/wai-app-file-cgi.haddock

haddock-html:         /usr/share/doc/haskell-wai-app-file-cgi/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-wai-app-file-cgi-3.1.11-3-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-wai-app-file-cgi.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 wai-app-file-cgi
version:              3.1.11
visibility:           public
id:                   wai-app-file-cgi-3.1.11-4EnFdxY471B6U5BXlZRXSf
key:                  wai-app-file-cgi-3.1.11-4EnFdxY471B6U5BXlZRXSf
license:              BSD-3-Clause
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Kazu Yamamoto <kazu@iij.ad.jp>
homepage:             http://www.mew.org/~kazu/proj/mighttpd/
synopsis:             File/CGI/Rev Proxy App of WAI
description:
    This WAI application library handles static files,
    executes CGI scripts, and serves as a reverse proxy
    (including EventSource).

category:             Web, Yesod
abi:                  c88c44dfd408c4c4fb36a2e49a9ff2f8
exposed:              True
exposed-modules:      Network.Wai.Application.Classic
hidden-modules:
    Network.Wai.Application.Classic.CGI
    Network.Wai.Application.Classic.Conduit
    Network.Wai.Application.Classic.Def
    Network.Wai.Application.Classic.EventSource
    Network.Wai.Application.Classic.Field
    Network.Wai.Application.Classic.File
    Network.Wai.Application.Classic.FileInfo
    Network.Wai.Application.Classic.Header
    Network.Wai.Application.Classic.Lang
    Network.Wai.Application.Classic.Path
    Network.Wai.Application.Classic.Redirect
    Network.Wai.Application.Classic.Status
    Network.Wai.Application.Classic.Types
    Network.Wai.Application.Classic.RevProxy

import-dirs:          /usr/lib/ghc-9.4.8/site-local/wai-app-file-cgi-3.1.11
library-dirs:         /usr/lib/ghc-9.4.8/site-local/wai-app-file-cgi-3.1.11
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/wai-app-file-cgi-3.1.11
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-wai-app-file-cgi
hs-libraries:         HSwai-app-file-cgi-3.1.11-4EnFdxY471B6U5BXlZRXSf
depends:
    array-0.5.4.0 attoparsec-0.14.4-LQtEgQtiyVz1VW0BNcPBCE
    base-4.17.2.1 bytestring-0.11.5.3
    case-insensitive-1.2.1.0-42k9iOSknrb4MqDPwxdyM4
    conduit-1.3.6.1-2pVpKBDXmhu8qGH9ehT40y
    conduit-extra-1.3.8-6EmNFogxH9m3yVrdAYfwkX containers-0.6.7
    data-default-class-0.1.2.2-2EcHBs5cfSFLku8331ZnRi directory-1.3.7.1
    filepath-1.4.2.2 http-client-0.7.19-CGIiAJO6qfCADepj1ASGVk
    http-conduit-2.3.9.1-1ZtBudtkVKQHTNrIHwzYXd
    http-date-0.0.11-3P2nwTg4MOe15PKmK6qrSI
    http-types-0.12.4-7VKWb71irDD4uKtGM0MrBb
    mime-types-0.1.2.0-3JrdaebXJwiILES3glDFuq
    network-3.1.4.0-IC0hdE8eZqJ6PeeNglfLy3 process-1.6.18.0
    sockaddr-0.0.1-C5LXtp2dIgEE1QqXhWpaQL
    static-hash-0.0.2-IGQWXf4MykG1ZDU3l0N2Yz text-2.0.2
    transformers-0.5.6.2 unix-2.7.3 wai-3.2.4-9UOcSkHEAzRImuC2gWdKbJ
    wai-conduit-3.0.0.4-CoIkMdh1QeFR8b8fbzlt8
    warp-3.4.0-ElI89jnrDVYITHcf4bOOtL
    word8-0.1.3-H2XlNdB8B5CGwrdA9Iis9I

haddock-interfaces:
    /usr/share/doc/haskell-wai-app-file-cgi/html/wai-app-file-cgi.haddock

haddock-html:         /usr/share/doc/haskell-wai-app-file-cgi/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
